==> cpgames-0.1.0.tar.gz: cpgames-0.1.0/README.md <==
<div align="center">
  <img src="./docs/logo.png" width="600"/>
</div>
<br />

[![docs](https://img.shields.io/badge/docs-latest-blue)](https://cpgames.readthedocs.io/zh/latest/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cpgames)](https://pypi.org/project/cpgames/)
[![PyPI](https://img.shields.io/pypi/v/cpgames)](https://pypi.org/project/cpgames)
[![license](https://img.shields.io/github/license/CharlesPikachu/Games.svg)](https://github.com/CharlesPikachu/Games/blob/master/LICENSE)
[![PyPI - Downloads](https://pepy.tech/badge/cpgames)](https://pypi.org/project/cpgames/)
[![issue resolution](https://isitmaintained.com/badge/resolution/CharlesPikachu/Games.svg)](https://github.com/CharlesPikachu/Games/issues)
[![open issues](https://isitmaintained.com/badge/open/CharlesPikachu/Games.svg)](https://github.com/CharlesPikachu/Games/issues)

Documents: https://cpgames.readthedocs.io/zh/latest/


# Games
```
Create interesting games by pure python.
You can star this repository to keep track of the project if it's helpful for you, thank you for your support.
```


# Statement
```
Most of the game materals(including music, fonts and pictures) in this repository are collected from the web, copyright belongs to the original author.
This repository is created just for learning python(Commercial prohibition).
```


# Support List
|   ID      |  English Name             |  Chinese Name           |   Core Code                                                |   Introduction                                               |
|   :----:  |  :----:                   |  :----:                 |   :----:                                                   |   :----:                                                     |
|   Game1   |  bunnybadger              |  兔子和獾(射击游戏)     |   [click](./cpgames/modules/core/bunnybadger)              |   [click](https://mp.weixin.qq.com/s/_-AChGldQzdwXN-ljcCMFQ) |
|   Game2   |  voicecontrolpikachu      |  仿八分音符的声控小游戏 |   [click](./cpgames/modules/core/voicecontrolpikachu)      |   [click](https://mp.weixin.qq.com/s/NmK5fAMoOHahOf6OvV6XFA) | 
|   Game3   |  puzzlepieces             |  拼图小游戏             |   [click](./cpgames/modules/core/puzzlepieces)             |   [click](https://mp.weixin.qq.com/s/tcmrbNCptka2ZTfEs-W_Lg) |
|   Game4   |  ski                      |  滑雪游戏               |   [click](./cpgames/modules/core/ski)                      |   [click](https://mp.weixin.qq.com/s/2MVTEa4ut9TOAgBOOWEUSg) |
|   Game5   |  tankwar                  |  经典坦克大战小游戏     |   [click](./cpgames/modules/core/tankwar)                  |   [click](https://mp.weixin.qq.com/s/1xXULpT36P7LTO5HDbjptg) |
|   Game6   |  flappybird               |  飞扬的小鸟小游戏       |   [click](./cpgames/modules/core/flappybird)               |   [click](https://mp.weixin.qq.com/s/44CZjwvjnH0kkkKIn5U9Uw) |
|   Game7   |  trexrush                 |  仿谷歌浏览器小恐龙游戏 |   [click](./cpgames/modules/core/trexrush)                 |   [click](https://mp.weixin.qq.com/s/PnvcSBe0Va3GVIodGIjYRg) |
|   Game8   |  towerdefense             |  塔防游戏               |   [click](./cpgames/modules/core/towerdefense)	           |   [click](https://mp.weixin.qq.com/s/mcnN3dF5tzWlRg91cnWTEw) |
|   Game9   |  catchcoins               |  接金币小游戏           |   [click](./cpgames/modules/core/catchcoins)	           |   [click](https://mp.weixin.qq.com/s/ZmMm7MKo7VyWZUAHEe9_JQ) |
|   Game10  |  aircraftwar              |  飞机大战               |   [click](./cpgames/modules/core/catchcoins)               |   [click](https://mp.weixin.qq.com/s/n-f_6sh8bB7-dtIFJLbnFg) |
|   Game11  |  tetris                   |  俄罗斯方块             |   [click](./cpgames/modules/core/tetris)                   |   [click](https://mp.weixin.qq.com/s/KFqpjmH6juZ2K8uKOoEaaA) |
|   Game12  |  sokoban                  |  推箱子                 |   [click](./cpgames/modules/core/sokoban)                  |   [click](https://mp.weixin.qq.com/s/y6CZd4h3uo7602LrI7aFdQ) |
|   Game13  |  alieninvasion            |  外星人入侵小游戏       |   [click](./cpgames/modules/core/alieninvasion)            |   [click](https://mp.weixin.qq.com/s/9UylZkV3sVTQLjThIaVObg) |
|   Game14  |  pacman                   |  吃豆人小游戏           |   [click](./cpgames/modules/core/pacman)                   |   [click](https://mp.weixin.qq.com/s/UBVLDW2T-Y6R-0IaRfu81Q) |
|   Game15  |  gemgem                   |  消消乐                 |   [click](./cpgames/modules/core/gemgem)                   |   [click](https://mp.weixin.qq.com/s/H0dFwoEcJT-JPKfNvPt2Kw) |
|   Game16  |  twentyfourpoint          |  24点小游戏             |   [click](./cpgames/modules/core/twentyfourpoint)          |   [click](https://mp.weixin.qq.com/s/raronw7X0WlntI48nUOvoQ) |
|   Game17  |  pingpong                 |  乒乓球小游戏           |   [click](./cpgames/modules/core/pingpong)                 |   [click](https://mp.weixin.qq.com/s/C6v0Zj8-fhysqRQ_lcEZIQ) |
|   Game18  |  breakoutclone            |  打砖块小游戏           |   [click](./cpgames/modules/core/breakoutclone)            |   [click](https://mp.weixin.qq.com/s/9tNVTA06dFthdugNs3TePA) |
|   Game19  |  bomberman                |  炸弹人小游戏           |   [click](./cpgames/modules/core/bomberman)                |   [click](https://mp.weixin.qq.com/s/XzB_cJMFEtz6p_MvqiaCrA) |
|   Game20  |  maze                     |  走迷宫小游戏           |   [click](./cpgames/modules/core/maze)                     |   [click](https://mp.weixin.qq.com/s/s9jburcC4WaOO_0ce54-Rg) |
|   Game21  |  whacamole                |  打地鼠                 |   [click](./cpgames/modules/core/whacamole)                |   [click](https://mp.weixin.qq.com/s/OFtW2Lx5i0Y9GXrF_PyqaA) |
|   Game22  |  gobang                   |  五子棋小游戏           |   [click](./cpgames/modules/core/gobang)                   |   [click](https://mp.weixin.qq.com/s/79aBuK_EytVAbDp5hY8cHA) |
|   Game23  |  twozerofoureight         |  2048小游戏             |   [click](./cpgames/modules/core/twozerofoureight)         |   [click](https://mp.weixin.qq.com/s/WJhg4J0MuuEcmDasRzuE9Q) |
|   Game24  |  greedysnake              |  贪吃蛇小游戏           |   [click](./cpgames/modules/core/greedysnake)              |   [click](https://mp.weixin.qq.com/s/YdRLYz4BnfgRZMYqKvDnRA) |
|   Game25  |  minesweeper              |  扫雷小游戏             |   [click](./cpgames/modules/core/minesweeper)              |   [click](https://mp.weixin.qq.com/s/O2nKNsWUigrKomW3l29Zlw) |
|   Game26  |  angrybirds               |  愤怒的小鸟             |   [click](./cpgames/modules/core/angrybirds)               |   [click](https://mp.weixin.qq.com/s/-Z_4PEF7f3ZS1CKd9D6Brg) |
|   Game27  |  flipcardbymemory         |  记忆翻牌小游戏         |   [click](./cpgames/modules/core/flipcardbymemory)         |   [click](https://mp.weixin.qq.com/s/H5UisWDWubdaQEBo-sH6iA) |


# Install

#### Whl install
```sh
wget https://github.com/CharlesPikachu/Games/releases/download/v0.1.0/cpgames-0.1.0-py3-none-any.whl
pip install cpgames-0.1.0-py3-none-any.whl
```

#### Pip install
```
run "pip install cpgames"
```

#### Source code install
```sh
(1) Offline
Step1: git clone https://github.com/CharlesPikachu/Games.git
Step2: cd Games -> run "python setup.py install"
(2) Online
run "pip install git+https://github.com/CharlesPikachu/Games.git@master"
```


# Quick Start
```python
import random
from cpgames import cpgames

game_client = cpgames.CPGames()
all_supports = game_client.getallsupported()
game_client.execute(random.choice(list(all_supports.values())))
```


# Screenshot
![img](./docs/screenshot.gif)


# Projects in Charles_pikachu
- [Games](https://github.com/CharlesPikachu/Games): Create interesting games by pure python.
- [DecryptLogin](https://github.com/CharlesPikachu/DecryptLogin): APIs for loginning some websites by using requests.
- [Musicdl](https://github.com/CharlesPikachu/musicdl): A lightweight music downloader written by pure python.
- [Videodl](https://github.com/CharlesPikachu/videodl): A lightweight video downloader written by pure python.
- [Pytools](https://github.com/CharlesPikachu/pytools): Some useful tools written by pure python.
- [PikachuWeChat](https://github.com/CharlesPikachu/pikachuwechat): Play WeChat with itchat-uos.


# Citation
If you use this project in your research, please cite this project.
```
@misc{games2020,
    author = {Zhenchao Jin},
    title = {Games: Create interesting games by pure python},
    year = {2020},
    publisher = {GitHub},
    journal = {GitHub repository},
    howpublished = {\url{https://github.com/CharlesPikachu/Games}},
}
```


# More
#### WeChat Official Accounts
*Charles_pikachu*  
![img](./docs/pikachu.jpg)

==> cpgames-0.1.1.tar.gz: cpgames-0.1.1/README.md <==
<div align="center">
  <img src="./docs/logo.png" width="600"/>
</div>
<br />

[![docs](https://img.shields.io/badge/docs-latest-blue)](https://cpgames.readthedocs.io/zh/latest/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cpgames)](https://pypi.org/project/cpgames/)
[![PyPI](https://img.shields.io/pypi/v/cpgames)](https://pypi.org/project/cpgames)
[![license](https://img.shields.io/github/license/CharlesPikachu/Games.svg)](https://github.com/CharlesPikachu/Games/blob/master/LICENSE)
[![PyPI - Downloads](https://pepy.tech/badge/cpgames)](https://pypi.org/project/cpgames/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/cpgames?style=flat-square)](https://pypi.org/project/cpgames/)
[![issue resolution](https://isitmaintained.com/badge/resolution/CharlesPikachu/Games.svg)](https://github.com/CharlesPikachu/Games/issues)
[![open issues](https://isitmaintained.com/badge/open/CharlesPikachu/Games.svg)](https://github.com/CharlesPikachu/Games/issues)

Documents: http://cpgames.readthedocs.io/


# Games
```
Create interesting games by pure python.
You can star this repository to keep track of the project if it's helpful for you, thank you for your support.
```


# Statement
```
Most of the game materals(including music, fonts and pictures) in this repository are collected from the web, copyright belongs to the original author.
This repository is created just for learning python(Commercial prohibition).
```


# Support List
|   ID      |  English Name             |  Chinese Name           |   Core Code                                                |   Introduction                                               |
|   :----:  |  :----:                   |  :----:                 |   :----:                                                   |   :----:                                                     |
|   Game1   |  bunnybadger              |  兔子和獾(射击游戏)     |   [click](./cpgames/modules/core/bunnybadger)              |   [click](https://mp.weixin.qq.com/s/_-AChGldQzdwXN-ljcCMFQ) |
|   Game2   |  voicecontrolpikachu      |  仿八分音符的声控小游戏 |   [click](./cpgames/modules/core/voicecontrolpikachu)      |   [click](https://mp.weixin.qq.com/s/NmK5fAMoOHahOf6OvV6XFA) | 
|   Game3   |  puzzlepieces             |  拼图小游戏             |   [click](./cpgames/modules/core/puzzlepieces)             |   [click](https://mp.weixin.qq.com/s/tcmrbNCptka2ZTfEs-W_Lg) |
|   Game4   |  ski                      |  滑雪游戏               |   [click](./cpgames/modules/core/ski)                      |   [click](https://mp.weixin.qq.com/s/2MVTEa4ut9TOAgBOOWEUSg) |
|   Game5   |  tankwar                  |  经典坦克大战小游戏     |   [click](./cpgames/modules/core/tankwar)                  |   [click](https://mp.weixin.qq.com/s/1xXULpT36P7LTO5HDbjptg) |
|   Game6   |  flappybird               |  飞扬的小鸟小游戏       |   [click](./cpgames/modules/core/flappybird)               |   [click](https://mp.weixin.qq.com/s/44CZjwvjnH0kkkKIn5U9Uw) |
|   Game7   |  trexrush                 |  仿谷歌浏览器小恐龙游戏 |   [click](./cpgames/modules/core/trexrush)                 |   [click](https://mp.weixin.qq.com/s/PnvcSBe0Va3GVIodGIjYRg) |
|   Game8   |  towerdefense             |  塔防游戏               |   [click](./cpgames/modules/core/towerdefense)	           |   [click](https://mp.weixin.qq.com/s/mcnN3dF5tzWlRg91cnWTEw) |
|   Game9   |  catchcoins               |  接金币小游戏           |   [click](./cpgames/modules/core/catchcoins)	           |   [click](https://mp.weixin.qq.com/s/ZmMm7MKo7VyWZUAHEe9_JQ) |
|   Game10  |  aircraftwar              |  飞机大战               |   [click](./cpgames/modules/core/catchcoins)               |   [click](https://mp.weixin.qq.com/s/n-f_6sh8bB7-dtIFJLbnFg) |
|   Game11  |  tetris                   |  俄罗斯方块             |   [click](./cpgames/modules/core/tetris)                   |   [click](https://mp.weixin.qq.com/s/KFqpjmH6juZ2K8uKOoEaaA) |
|   Game12  |  sokoban                  |  推箱子                 |   [click](./cpgames/modules/core/sokoban)                  |   [click](https://mp.weixin.qq.com/s/y6CZd4h3uo7602LrI7aFdQ) |
|   Game13  |  alieninvasion            |  外星人入侵小游戏       |   [click](./cpgames/modules/core/alieninvasion)            |   [click](https://mp.weixin.qq.com/s/9UylZkV3sVTQLjThIaVObg) |
|   Game14  |  pacman                   |  吃豆人小游戏           |   [click](./cpgames/modules/core/pacman)                   |   [click](https://mp.weixin.qq.com/s/UBVLDW2T-Y6R-0IaRfu81Q) |
|   Game15  |  gemgem                   |  消消乐                 |   [click](./cpgames/modules/core/gemgem)                   |   [click](https://mp.weixin.qq.com/s/H0dFwoEcJT-JPKfNvPt2Kw) |
|   Game16  |  twentyfourpoint          |  24点小游戏             |   [click](./cpgames/modules/core/twentyfourpoint)          |   [click](https://mp.weixin.qq.com/s/raronw7X0WlntI48nUOvoQ) |
|   Game17  |  pingpong                 |  乒乓球小游戏           |   [click](./cpgames/modules/core/pingpong)                 |   [click](https://mp.weixin.qq.com/s/C6v0Zj8-fhysqRQ_lcEZIQ) |
|   Game18  |  breakoutclone            |  打砖块小游戏           |   [click](./cpgames/modules/core/breakoutclone)            |   [click](https://mp.weixin.qq.com/s/9tNVTA06dFthdugNs3TePA) |
|   Game19  |  bomberman                |  炸弹人小游戏           |   [click](./cpgames/modules/core/bomberman)                |   [click](https://mp.weixin.qq.com/s/XzB_cJMFEtz6p_MvqiaCrA) |
|   Game20  |  maze                     |  走迷宫小游戏           |   [click](./cpgames/modules/core/maze)                     |   [click](https://mp.weixin.qq.com/s/s9jburcC4WaOO_0ce54-Rg) |
|   Game21  |  whacamole                |  打地鼠                 |   [click](./cpgames/modules/core/whacamole)                |   [click](https://mp.weixin.qq.com/s/OFtW2Lx5i0Y9GXrF_PyqaA) |
|   Game22  |  gobang                   |  五子棋小游戏           |   [click](./cpgames/modules/core/gobang)                   |   [click](https://mp.weixin.qq.com/s/79aBuK_EytVAbDp5hY8cHA) |
|   Game23  |  twozerofoureight         |  2048小游戏             |   [click](./cpgames/modules/core/twozerofoureight)         |   [click](https://mp.weixin.qq.com/s/WJhg4J0MuuEcmDasRzuE9Q) |
|   Game24  |  greedysnake              |  贪吃蛇小游戏           |   [click](./cpgames/modules/core/greedysnake)              |   [click](https://mp.weixin.qq.com/s/YdRLYz4BnfgRZMYqKvDnRA) |
|   Game25  |  minesweeper              |  扫雷小游戏             |   [click](./cpgames/modules/core/minesweeper)              |   [click](https://mp.weixin.qq.com/s/O2nKNsWUigrKomW3l29Zlw) |
|   Game26  |  angrybirds               |  愤怒的小鸟             |   [click](./cpgames/modules/core/angrybirds)               |   [click](https://mp.weixin.qq.com/s/-Z_4PEF7f3ZS1CKd9D6Brg) |
|   Game27  |  flipcardbymemory         |  记忆翻牌小游戏         |   [click](./cpgames/modules/core/flipcardbymemory)         |   [click](https://mp.weixin.qq.com/s/H5UisWDWubdaQEBo-sH6iA) |
|   Game28  |  magictower               |  魔塔小游戏             |   [click](./cpgames/modules/core/magictower)               |   [click]()                                                  |


# Install

#### Whl install
```sh
wget https://github.com/CharlesPikachu/Games/releases/download/v0.1.1/cpgames-0.1.1-py3-none-any.whl
pip install cpgames-0.1.1-py3-none-any.whl
```

#### Pip install
```
run "pip install cpgames"
```

#### Source code install
```sh
(1) Offline
Step1: git clone https://github.com/CharlesPikachu/Games.git
Step2: cd Games -> run "python setup.py install"
(2) Online
run "pip install git+https://github.com/CharlesPikachu/Games.git@master"
```


# Quick Start
```python
import random
from cpgames import cpgames

game_client = cpgames.CPGames()
all_supports = game_client.getallsupported()
game_client.execute(random.choice(list(all_supports.values())))
```


# Screenshot
![img](./docs/screenshot.gif)


# Projects in Charles_pikachu
- [Games](https://github.com/CharlesPikachu/Games): Create interesting games by pure python.
- [DecryptLogin](https://github.com/CharlesPikachu/DecryptLogin): APIs for loginning some websites by using requests.
- [Musicdl](https://github.com/CharlesPikachu/musicdl): A lightweight music downloader written by pure python.
- [Videodl](https://github.com/CharlesPikachu/videodl): A lightweight video downloader written by pure python.
- [Pytools](https://github.com/CharlesPikachu/pytools): Some useful tools written by pure python.
- [PikachuWeChat](https://github.com/CharlesPikachu/pikachuwechat): Play WeChat with itchat-uos.
- [Pydrawing](https://github.com/CharlesPikachu/pydrawing): Beautify your image or video.
- [ImageCompressor](https://github.com/CharlesPikachu/imagecompressor): Image compressors written by pure python.
- [FreeProxy](https://github.com/CharlesPikachu/freeproxy): Collecting free proxies from internet.
- [Paperdl](https://github.com/CharlesPikachu/paperdl): Search and download paper from specific websites.
- [Sciogovterminal](https://github.com/CharlesPikachu/sciogovterminal): Browse "The State Council Information Office of the People's Republic of China" in the terminal.
- [CodeFree](https://github.com/CharlesPikachu/codefree): Make no code a reality.
- [DeepLearningToys](https://github.com/CharlesPikachu/deeplearningtoys): Some deep learning toys implemented in pytorch.
- [DataAnalysis](https://github.com/CharlesPikachu/dataanalysis): Some data analysis projects in charles_pikachu.


# Citation
If you use this project in your research, please cite this project.
```
@misc{games2020,
    author = {Zhenchao Jin},
    title = {Games: Create interesting games by pure python},
    year = {2020},
    publisher = {GitHub},
    journal = {GitHub repository},
    howpublished = {\url{https://github.com/CharlesPikachu/Games}},
}
```


# More

#### WeChat Official Accounts
*Charles_pikachu*  
![img](./docs/pikachu.jpg)
